@@ -4,15 +4,16 @@ use utf8;
 
 package Dist::Zilla::Plugin::CopyFilesFromBuild;
 # ABSTRACT: Copy (or move) specific files after building (for SCM inclusion, etc.)
-$Dist::Zilla::Plugin::CopyFilesFromBuild::VERSION = '0.151680';
+$Dist::Zilla::Plugin::CopyFilesFromBuild::VERSION = '0.161150';
 use Moose;
 use MooseX::Has::Sugar;
 with qw/ Dist::Zilla::Role::AfterBuild /;
 
 use File::Copy ();
-# use File::Slurp qw( read_file write_file );
 use List::Util 1.33 qw( any );
+use Path::Tiny;
 use Set::Scalar;
+
 # accept some arguments multiple times.
 sub mvp_multivalue_args { qw{ copy move } }
 
@@ -39,7 +40,7 @@ sub after_build {
         }
         my $src = $build_root->file( $path );
         if (-e $src) {
-            my $dest = $self->zilla->root->file( $src->basename );
+            my $dest = path($self->zilla->root)->child( $src->basename );
             File::Copy::copy "$src", "$dest"
                 or $self->log_fatal("Unable to copy $src to $dest: $!");
             $self->log("Copied $src to $dest");
@@ -122,7 +123,7 @@ Dist::Zilla::Plugin::CopyFilesFromBuild - Copy (or move) specific files after bu
 
 =head1 VERSION
 
-version 0.151680
+version 0.161150
 
 =head1 SYNOPSIS
 
